<?php

require_once 'connect.user.php';

// change the following file contents to adjust login etc.
require_once('logindetails.php');

// set up error handling as recommended using example here: http://us2.php.net/manual/en/class.errorexception.php
// note this also automatically puts PHP into a strict mode, which is good!
function exception_error_handler($errno, $errstr, $errfile, $errline) {
    throw new ErrorException($errstr, $errno, 0, $errfile, $errline);
}

set_error_handler("exception_error_handler");

// Interfaces: 
interface TimeTrexClientFactory {

    public function makeTimeTrexClient();
}

interface TimeTrexClient {

    public function run();
}

// Concrete implementations:
class TimeTrexCommandLineClientFactory implements TimeTrexClientFactory {

    public function makeTimeTrexClient() {
        return new TimeTrexCommandLineClient();
    }

}

class TimeTrexCommandLineClient implements TimeTrexClient {

    public function getTimeTrexSessionId() {
        return $GLOBALS['TIMETREX_SESSION_ID'];
    }

    // full login, to be used at start of application, or after reset
    public function run() {
        // Reconnecting to server
        $GLOBALS['TIMETREX_SESSION_ID'] = FALSE;  // clear any existing Session token
        return $this->login();
    }

    // simple version of login, used to log back in after switchUser
    public function login() {
        $api_session = new TimeTrexClientAPI();
        try {
            $api_session->Login($GLOBALS['TIMETREX_USERNAME'], $GLOBALS['TIMETREX_PASSWORD']);
        } catch (Exception $e) {
            echo "ERROR: Login failed with the following message:\n" . $e->getMessage();
        }
        return $api_session;
    }

    // attempt to switch to the user with the given user ID. 
    // Note this requires the modified version of APIAuthentication.class.php
    // to be installed on the TimeTrex Server. 
    // return true if successful. 
    public function switchUser($userId) {
        $result = false;
        $auth_obj = new TimeTrexClientAPI('Authentication');
        if ($auth_obj == false) {
            echo "CONNECTION ERROR - auth_obj\n";
        } else {
            $auth_obj->switchUser($userId);
            if ($auth_obj == false) {
                echo "CONNECTION ERROR - switchUser\n";
            } else {
                $result = true;
            }
        }
        return $result;
    }

}
